@@ -4,19 +4,19 @@
  *
  * Copyright (C) 2010 Steve Frécinaux
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * libpeas is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ * libpeas is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -24,7 +24,6 @@
 #endif
 
 #include "peas-extension.h"
-#include "peas-extension-wrapper.h"
 #include "peas-introspection.h"
 
 /**
@@ -67,6 +66,9 @@ peas_extension_get_type (void)
   return G_TYPE_OBJECT;
 }
 
+static
+G_DEFINE_QUARK (peas-extension-type, extension_type)
+
 static GICallableInfo *
 get_method_info (PeasExtension *exten,
                  const gchar   *method_name,
@@ -76,7 +78,6 @@ get_method_info (PeasExtension *exten,
   GType exten_type;
   GType *interfaces;
   GICallableInfo *method_info;
-  gboolean must_free_interfaces = FALSE;
 
   /* Must prioritize the initial GType */
   exten_type = peas_extension_get_extension_type (exten);
@@ -90,15 +91,7 @@ get_method_info (PeasExtension *exten,
       return method_info;
     }
 
-  if (PEAS_IS_EXTENSION_WRAPPER (exten))
-    {
-      interfaces = PEAS_EXTENSION_WRAPPER (exten)->interfaces;
-    }
-  else
-    {
-      must_free_interfaces = TRUE;
-      interfaces = g_type_interfaces (G_TYPE_FROM_INSTANCE (exten), NULL);
-    }
+  interfaces = g_type_interfaces (G_TYPE_FROM_INSTANCE (exten), NULL);
 
   for (i = 0; interfaces[i] != G_TYPE_INVALID; ++i)
     {
@@ -113,12 +106,10 @@ get_method_info (PeasExtension *exten,
         }
     }
 
-  if (must_free_interfaces)
-    g_free (interfaces);
-
   if (method_info == NULL)
     g_warning ("Could not find the interface for method '%s'", method_name);
 
+  g_free (interfaces);
   return method_info;
 }
 
@@ -135,14 +126,8 @@ get_method_info (PeasExtension *exten,
 GType
 peas_extension_get_extension_type (PeasExtension *exten)
 {
-  if (PEAS_IS_EXTENSION_WRAPPER (exten))
-    {
-      return peas_extension_wrapper_get_extension_type (PEAS_EXTENSION_WRAPPER (exten));
-    }
-  else
-    {
-      return (GType) g_object_get_data (G_OBJECT (exten), "peas-extension-type");
-    }
+  return GPOINTER_TO_SIZE (g_object_get_qdata (G_OBJECT (exten),
+                                               extension_type_quark ()));
 }
 
 /**
@@ -169,7 +154,7 @@ peas_extension_get_extension_type (PeasExtension *exten)
  *
  * Return value: %TRUE on successful call.
  *
- * Deprecated: 1.2: Use the dynamically implemented interface instead.
+ * Deprecated: 1.2: Use the interface directly instead.
  */
 gboolean
 peas_extension_call (PeasExtension *exten,
@@ -201,7 +186,7 @@ peas_extension_call (PeasExtension *exten,
  *
  * Return value: %TRUE on successful call.
  *
- * Deprecated: 1.2: Use the dynamically implemented interface instead.
+ * Deprecated: 1.2: Use the interface directly instead.
  */
 gboolean
 peas_extension_call_valist (PeasExtension *exten,
@@ -256,7 +241,7 @@ peas_extension_call_valist (PeasExtension *exten,
  *
  * Return value: %TRUE on successful call.
  *
- * Deprecated: 1.2: Use the dynamically implemented interface instead.
+ * Deprecated: 1.2: Use the interface directly instead.
  */
 gboolean
 peas_extension_callv (PeasExtension *exten,
@@ -277,17 +262,8 @@ peas_extension_callv (PeasExtension *exten,
   if (method_info == NULL)
     return FALSE;
 
-  if (PEAS_IS_EXTENSION_WRAPPER (exten))
-    {
-      success = peas_extension_wrapper_callv (PEAS_EXTENSION_WRAPPER (exten),
-                                              interface, method_info,
-                                              method_name, args, return_value);
-    }
-  else
-    {
-      success = peas_gi_method_call (G_OBJECT (exten), method_info, interface,
-                                     method_name, args, return_value);
-    }
+  success = peas_gi_method_call (G_OBJECT (exten), method_info, interface,
+                                 method_name, args, return_value);
 
   g_base_info_unref (method_info);
   return success;
